
## Classes

<dl>
<dt><a href="#Tag">Tag</a></dt>
<dd></dd>
<dt><a href="#Template">Template</a></dt>
<dd></dd>
</dl>

## Constants

<dl>
<dt><a href="#html">html</a> ⇒ <code><a href="#Template">Template</a></code></dt>
<dd><p>Tag function for your html template</p>
<pre><code class="language-javascript">html`There are ${numberOfLights} lights`</code></pre>
</dd>
</dl>

## Functions

<dl>
<dt><a href="#encodeHtml">encodeHtml(str)</a> ⇒ <code>String</code></dt>
<dd><p>Encodes a string to be html-safe by turning certain characters into their html encoded counterpart</p>
</dd>
</dl>

<a name="Tag"></a>

## Tag


* [Tag](#Tag)
    * [new Tag(encoder)](#new_Tag_new)
    * [.tag(lits, ...values)](#Tag+tag)
    * [.join(parts, separator)](#Tag+join)
    * [.safe(value)](#Tag+safe)

<a name="new_Tag_new"></a>

### new Tag(encoder)
Class that contains methods for creating Template objects


| Param | Type | Description |
| --- | --- | --- |
| encoder | <code>function</code> | Function for encoding non-literal values |

<a name="Tag+tag"></a>

### tag.tag(lits, ...values)
Template tag function that returns a new template object

**Kind**: instance method of [<code>Tag</code>](#Tag)

| Param | Type | Description |
| --- | --- | --- |
| lits | <code>Array</code> | Literals values to use in the template |
| ...values | <code>any</code> | Variables to use in the template |

<a name="Tag+join"></a>

### tag.join(parts, separator)
Create a Template that joins an array of values together

**Kind**: instance method of [<code>Tag</code>](#Tag)

| Param | Type | Default | Description |
| --- | --- | --- | --- |
| parts | <code>Array</code> |  | Values to join |
| separator | <code>\*</code> | <code>,</code> | Literal to use as the joining string |

<a name="Tag+safe"></a>

### tag.safe(value)
Cast the value to a Template so that it can be rendered without encoding it

**Kind**: instance method of [<code>Tag</code>](#Tag)

| Param | Type | Description |
| --- | --- | --- |
| value | <code>\*</code> | Value to cast |

<a name="Template"></a>

## Template


* [Template](#Template)
    * [new Template(literals, variables, encode)](#new_Template_new)
    * [.with(props)](#Template+with) ⇒ <code>Object</code>
    * [.generate(replace)](#Template+generate) ⇒ <code>AsyncIterator</code>
    * [.render(replace)](#Template+render)

<a name="new_Template_new"></a>

### new Template(literals, variables, encode)
Create an object representing the template and its values.


| Param | Type | Description |
| --- | --- | --- |
| literals | <code>Array</code> | Parts of the template that will not be encoded |
| variables | <code>Array</code> | Parts of the template that will be encoded |
| encode | <code>function</code> | The function that encodes the variables |

<a name="Template+with"></a>

### template.with(props) ⇒ <code>Object</code>
Tag this template with extra properites
May be useful in conjunction with certain replacer functions

**Kind**: instance method of [<code>Template</code>](#Template)
**Returns**: <code>Object</code> - A new object with the passed properties, and the template as the prototype

| Param | Type | Description |
| --- | --- | --- |
| props | <code>Object</code> | Properties to assign |

<a name="Template+generate"></a>

### template.generate(replace) ⇒ <code>AsyncIterator</code>
Yields an async iterator that renders the template to a string.
Template variables are handled in the following way:
	- Strings will have html characters replaced with their html entities
	- Nested Templates will be rendered
	- Promises will be resolved
	- Iterables will be flattened (including arrays, sync and async iterators)
A `replace` function can be passed to alter individual variables before they are encoded.
If supplied, this replace function will be passed down to all nested templates.

**Kind**: instance method of [<code>Template</code>](#Template)

| Param | Type | Description |
| --- | --- | --- |
| replace | <code>function</code> | Function that can be used to replace individual variables |

<a name="Template+render"></a>

### template.render(replace)
Render the template to a string. If any of the variables are Promises, return value will be a promise.
Otherwise the return value will be a string.

**Kind**: instance method of [<code>Template</code>](#Template)

| Param | Type | Description |
| --- | --- | --- |
| replace | <code>function</code> | Function that can be used to replace individual variables |

<a name="html"></a>

## html ⇒ [<code>Template</code>](#Template)
Tag function for your html template

```javascript
html`There are ${numberOfLights} lights`
```


**Returns**: [<code>Template</code>](#Template) - The template object

* [html](#html) ⇒ [<code>Template</code>](#Template)
    * [.join](#html.join) ⇒ [<code>Template</code>](#Template)
    * [.safe](#html.safe) ⇒ [<code>Template</code>](#Template)
    * [.raw](#html.raw)

<a name="html.join"></a>

### html.join ⇒ [<code>Template</code>](#Template)
Creates a Template that joins together an array of values with an optional separator

```javascript
html.join([1,2,3,4,5], ' and ')
```

**Kind**: static property of [<code>html</code>](#html)

| Param | Type | Description |
| --- | --- | --- |
| values | <code>Array</code> | Values to join |
| separator | <code>String</code> | Separator to use, defaults to `,` |

<a name="html.safe"></a>

### html.safe ⇒ [<code>Template</code>](#Template)
Creates a new Tempalte using a value that won't be encoded when rendered, or passed as a value to another template.
Don't use this for unfiltered user input.

```javascript
html.safe(markdownToHtml('# Page title\n\n*Hello!*'));
```

**Kind**: static property of [<code>html</code>](#html)

| Param | Type | Description |
| --- | --- | --- |
| value | <code>String</code> | The value to use as a literal |

<a name="html.raw"></a>

### html.raw
Alias of html.safe

**Kind**: static property of [<code>html</code>](#html)
**See**: html.safe
<a name="encodeHtml"></a>

## encodeHtml(str) ⇒ <code>String</code>
Encodes a string to be html-safe by turning certain characters into their html encoded counterpart



| Param | Type | Description |
| --- | --- | --- |
| str | <code>String</code> | The string to replace html entities for |

