import Tag from './tag.js';

import encodeHtml from './encode-html.js';

const htmlTagger = Tag.create(encodeHtml);

/**
 * Tag function for your html template
 *
 * ```javascript
 * html`There are ${numberOfLights} lights`
 * ```
 *
 * @returns {Template} The template object
 */
const html = htmlTagger;

/**
 * Creates a Template that joins together an array of values with an optional separator
 *
 * ```javascript
 * html.join([1,2,3,4,5], ' and ')
 * ```
 *
 * @param {Array} values Values to join
 * @param {String} separator Separator to use, defaults to `,`
 * @returns {Template}
 */
html.join = htmlTagger.join;

/**
 * Creates a new Tempalte using a value that won't be encoded when rendered, or passed as a value to another template.
 * Don't use this for unfiltered user input.
 *
 * ```javascript
 * html.safe(markdownToHtml('# Page title\n\n*Hello!*'));
 * ```
 * @param {String} value The value to use as a literal
 * @returns {Template}
 */
html.safe = htmlTagger.safe;

/**
 * Alias of html.safe
 * @see html.safe
 */
html.raw = html.safe;

export default html;
